@@ -47,9 +47,10 @@ the following application events are fired exactly one time at startup in the fo
     the `on_app_build` application event has to be fired by the used GUI framework.
 
 .. hint::
-    depending on the used gui framework there can be more app start events. e.g. the :mod:`ae.kivy_app` module fires the
-    events `on_app_built` and `on_app_started` (all of them fired after `on_app_run` and `on_app_build`). see also
-    :ref:`kivy application events`.
+    depending on the used gui framework there can be more app start events. e.g. the :mod:`ae.kivy.apps` module fires
+    the events :meth:`~ae.kivy.apps.KivyMainApp.on_app_built` and :meth:`~ae.kivy.apps.KivyMainApp.on_app_started` (all
+    of them fired after :meth:`~ae.kivy.apps.KivyMainApp.on_app_run` and
+    :meth:`~ae.kivy.apps.KivyMainApp.on_app_build`). see also :ref:`kivy application events`.
 
 
 when an application gets stopped then the following events get fired in the following order:
@@ -66,8 +67,9 @@ when an application gets stopped then the following events get fired in the foll
     :meth:`~MainAppBase.stop_app` method.
 
 .. hint::
-    depending on the used gui framework there can be more events. e.g. the :mod:`ae.kivy_app` module fires the event
-    `on_app_stopped` (before `on_app_stop` respectively `on_app_quit`).
+    depending on the used gui framework there can be more events. e.g. the :mod:`~ae.kivy.apps` module fires the event
+    :meth:`~ae.kivy.apps.KivyMainApp.on_app_stopped` (before :meth:`~ae.kivy.apps.KivyMainApp.on_app_stop`
+    respectively :meth:`~ae.kivy.apps.KivyMainApp.on_app_quit`).
 
 
 application status
@@ -269,7 +271,8 @@ the close.
 
 .. hint::
     see the documentation of each popup class for more details on the features of popup classes (for Kivy apps e.g.
-    :class:`~ae.kivy_app.FlowDropDown`, :class:`~ae.kivy_app.FlowPopup` or :class:`~ae.kivy_app.FlowSelector`).
+    :class:`~ae.kivy.widgets.FlowDropDown`, :class:`~ae.kivy.widgets.FlowPopup` or
+    :class:`~ae.kivy.widgets.FlowSelector`).
 
 
 key press events
@@ -429,7 +432,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.3.90'
+__version__ = '0.3.91'
 
 
 APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name to store app state
@@ -444,7 +447,7 @@ THEME_DARK_FONT_COLOR = COLOR_WHITE             #: dark theme font color in rgba
 THEME_LIGHT_BACKGROUND_COLOR = COLOR_WHITE      #: light theme background color in rgba(0.0 ... 1.0)
 THEME_LIGHT_FONT_COLOR = COLOR_BLACK            #: light theme font color in rgba(0.0 ... 1.0)
 
-MIN_FONT_SIZE = 15.0                            #: minimum (s.a. :attr:`~ae.kivy_app.FrameworkApp.min_font_size`) and
+MIN_FONT_SIZE = 15.0                            #: minimum (s.a. :attr:`~ae.kivy.apps.FrameworkApp.min_font_size`) and
 MAX_FONT_SIZE = 99.0                            #: .. maximum font size in pixels
 
 
@@ -894,7 +897,8 @@ class MainAppBase(ConsoleApp, ABC):
                                 * `tap_widget`: optional tapped button widget instance (initiating this flow change).
 
                                 some of these keys get specified directly on the call of this method, e.g. via
-                                :attr:`~.kivy_app.FlowButton.tap_kwargs` or :attr:`~.kivy_app.FlowToggler.tap_kwargs`,
+                                :attr:`~ae.kivy.widgets.FlowButton.tap_kwargs` or
+                                :attr:`~ae.kivy.widgets.FlowToggler.tap_kwargs`,
                                 where others get added by the flow change confirmation handlers/callbacks.
 
         :return:                True if flow got confirmed by a declared custom flow change confirmation event handler
